<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="fa">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>برنامه پروکسی</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع پراکسی</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>آدرس IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>پورت</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>اختیاری</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>&quot;استفاده از پروکسی&quot; را در فهرست برنامه در لانچر پس از پیکربندی بررسی کنید</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>قطع اتصال</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>در حال اتصال</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>قطع اتصال</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>آیا مطمئن هستید که می خواهید این پیکربندی را حذف کنید؟</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>اتصال سیمی %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>هات اسپات</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>اتصال بی سیم %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>اتصال  PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN جدید</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>نوع VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>صادر</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>برنامه پروکسی</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>هات اسپات شخصی</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>جزئیات شبکه</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>پراکسی سیستم</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>آداپتور شبکه سیمی</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>افزودن اتصال شبکه</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>آداپتور شبکه بی سیم</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>اتصال به شبکه مخفی</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>اتصال PPPoE ایجاد کنید</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>وضعیت VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>ایجاد VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>وارد کردن VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع پراکسی</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>پیکربندی URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>آدرس IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>پورت</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>هات اسپات</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>ساخت هات اسپات</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>رابط</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>باند</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS اولیه</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>پیشوند</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>سرعت</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>اترنت</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>وصل نشد</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>آدرس MAC دستگاه</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>آدرس MAC کپی شده</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>شخصی سازی MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>کلی</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>کلی</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>این نام از قبل وجود دارد</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>اتصال - خودکار</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>هات اسپات</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>اضافه کردن تنظیمات</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>ساخت هات اسپات</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>آدرس IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>پیشوند</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>دستی</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>نادیده گرفتن</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>آدرس IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>تنها در منابع مربوطه اعمال می‌شود</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>روش</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>پیشوند</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>روش</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>دستی</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>نادیده گرفتن</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>جزئیات شبکه</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>پراکسی سیستم</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>برنامه پروکسی</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>جزئیات شبکه</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>غیر فعال</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>دستی</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>پیکربندی توسط مدیر شبکه</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>هات اسپات شخصی</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>خدمات</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>از تأیید اعتبار EAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>از تأیید اعتبار PAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>از تأیید اعتبار CHAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>از تأیید اعتبار MSCHAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>از تأیید اعتبار MSCHAPv2  خودداری کن</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>فشرده سازی داده BSD وجود ندارد</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>فاقد فشرده سازی تورمی داده ها</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>فشرده سازی هدر TCP وجود ندارد</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>بدون فیلد پروتکل فشرده سازی</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>بدون آدرس / کنترل فشرده سازی</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>بسته های اکو PPP ارسال کن</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>استفاده از MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>اتصال PPPoE ایجاد کنید</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>پراکسی سیستم</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع پراکسی</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>دستی</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>اختیاری</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>پورت</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>پراکسی HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>پراکسی HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>پراکسی FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>تنظیمات پروکسی را برای میزبان ها و دامنه های فوق نادیده بگیر</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>پیکربندی URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>امنیتی</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Protected EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>غیر فعال</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>ناشناس</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>احراز هویت شد</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>هردو</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>نسخه 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>نسخه 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>احراز هویت EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>هویت</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>گزینه های Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>کلید شخصی</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>مجوز CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>مجوز کاربر</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>آی دی ناشناس</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>تامین</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>فایل PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>احراز هویت داخلی</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>نسخه PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>پسورد شخصی</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>رمزعبور نامعتبر</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ </translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>امنیتی</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>کلید</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>نیازمند مورد امنیتی</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>رمزعبور نامعتبر</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ </translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>امنیتی</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>کلید</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN پیشرفته</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>شخصی سازی پورت درگاه</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>پورت درگاه</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>فاصله بین مذاکره را سفارشی کنید</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>بازه مذاکره</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>از LZO فشرده سازی داده استفاده کن</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>از اتصال TCP استفاده کن</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>استفاده از دستگاه TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>شخصی سازی تونل MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>سفارشی سازی حجم قطعه UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>حجم قطعه UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>تونل TCP MSS را محدود کنید</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>انتخاب تصادفی هاست ریموت</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN پیشرفته</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>سیسکو (پیش فرض)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>امن(پیش فرض)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>ضعیف</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ </translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T در صورت وجود (پیش فرض)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>همیشه NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>غیر فعال</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (پیش فرض)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>سرور (پیش فرض)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>دامنه</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>فروشنده</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>نسخه</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>رمزگذاری</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>حالت گذرگاه NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>امنیت پیشرو</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>پورت محلی</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>غیر فعال کردن تشخیص Dead Peer</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>فعال کردن IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>نام گروه</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>آی دی گروه</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>الگوریتم های Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>الگوریتم های Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>مجوز CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>پراکسی</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>به برنامه محافظت دربرابر تروجان سیسکو اجازه دهید</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>اسکریپت CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>مجوز کاربر</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>کلید شخصی</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>از FSID برای کلید پسورد استفاده کن</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>گواهینامه ها (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>گواهی های دارای رمز عبور (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>کلید استاتیک</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ذخیره شد</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>پرسیدن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>نیازی نیست</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>نوع احراز هویت</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>مجوز CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>مجوز کاربر</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>کلید شخصی</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>گزینه های Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>پسورد شخصی</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>سفارشی سازی جهت کلید</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>جهت کلید</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>ریموت آی پی</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>آی پی محلی</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>همه موجود (پیش فرض)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 بیتی (ایمنی کمتر )</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 بیتی (امن ترین)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>از تأیید اعتبار EAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>از تأیید اعتبار PAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>از تأیید اعتبار CHAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>از تأیید اعتبار MSCHAP خودداری کن</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>از تأیید اعتبار MSCHAPv2  خودداری کن</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>فشرده سازی داده BSD وجود ندارد</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>فاقد فشرده سازی تورمی داده ها</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>فشرده سازی هدر TCP وجود ندارد</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>بدون فیلد پروتکل فشرده سازی</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>بدون آدرس / کنترل فشرده سازی</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>بسته های اکو PPP ارسال کن</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>استفاده از MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>امنیتی</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>وضعیت VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>ایجاد VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>وارد کردن VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>خطای وارد کردن</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>تایید</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>نیازی نیست</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع پراکسی</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP سرور</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>پورت</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>هنگام عدم موفقیت شناسایی را مجددا بررسی کنید</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>فایل CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>نادیده گرفتن اخطارهای گواهی</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>استفاده از TLS Hostname Extensions</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>امنیت VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>پیش فرض</translation>
    </message>
    <message>
        <source>None</source>
        <translation>هیچ </translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>ذخیره شد</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>پرسیدن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>نیازی نیست</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>گزینه های Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>دامین NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP سرور</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>پورت</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>کلید شخصی</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>مجوز CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>نوع احراز هویت</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>مجوز کاربر</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>درخواست یک نشانی IP داخلی</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>اجرای کپسوله کردن udp</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>از فشرده سازی IP استفاده کن</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>پیشنهادات رمزگذاری سفارشی را فعال کن</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS احراز هویت</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>پیش فرض</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>کلاینت</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>سرور</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>موضوع متناسب</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>نوع مجوز ریموت</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>فایل کلید</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>سفارشی سازی جهت کلید</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>جهت کلید</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>ذخیره شد</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>پرسیدن</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>نیازی نیست</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>نام کاربری</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>گزینه های Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>نام گروه</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>رمزعبور گروه</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>از احراز هویت ترکیبی استفاده کن</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>فایل CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>ابتدا کابل شبکه را وصل کنید</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>آداپتور شبکه سیمی</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>افزودن اتصال شبکه</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>تنظیمات را انتخاب کنید</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>آداپتور شبکه بی سیم</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>بستن هات اسپات</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>اگر می خواهید به یک شبکه بی سیم وصل شوید ، هات اسپات را غیرفعال کنید</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>اتصال به شبکه مخفی</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>وصل نشد</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مورد نیاز</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>آدرس MAC دستگاه</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>شخصی سازی MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>